@@ -16,11 +16,9 @@
 #include "config/playerselector.h"
 #include "ui_generalsettings.h"
 // KDEGames
-#include <kdegames_version.h>
-#include <KStandardGameAction>
-#include <KgThemeSelector>
+#include <KGameStandardAction>
+#include <KGameThemeSelector>
 // KF
-#include <kwidgetsaddons_version.h>
 #include <KStandardGuiItem>
 #include <KActionCollection>
 #include <KMessageBox>
@@ -53,17 +51,13 @@ MainWindow::MainWindow()
     m_view = nullptr;
     m_scene = nullptr;
     m_playerSettings = new PlayerSettings();
-    m_themeProvider = new KgThemeProvider(QByteArray("Theme"), this);
-#if KDEGAMES_VERSION >= QT_VERSION_CHECK(7, 4, 0)
+    m_themeProvider = new KGameThemeProvider(QByteArray("Theme"), this);
     m_themeProvider->discoverThemes(QStringLiteral("themes"), QStringLiteral("granatier"));
-#else
-    m_themeProvider->discoverThemes(QByteArray("appdata"), QStringLiteral("themes"), QStringLiteral("granatier"));
-#endif
     // Set the window menus
-    KStandardGameAction::gameNew(this, &MainWindow::newGame, actionCollection());
-    //KStandardGameAction::highscores(this, &MainWindow::showHighscores, actionCollection());
+    KGameStandardAction::gameNew(this, &MainWindow::newGame, actionCollection());
+    //KGameStandardAction::highscores(this, &MainWindow::showHighscores, actionCollection());
     KStandardAction::preferences(this, &MainWindow::showSettings, actionCollection());
-    KStandardGameAction::quit(this, &MainWindow::close, actionCollection());
+    KGameStandardAction::quit(this, &MainWindow::close, actionCollection());
     auto* soundAction = new KToggleAction(i18n("&Play sounds"), this);
     soundAction->setChecked(Settings::sounds());
     actionCollection()->addAction( QStringLiteral( "sounds" ), soundAction);
@@ -141,20 +135,12 @@ void MainWindow::newGame()
     if (!m_game->getGameOver())
     {
         // Confirm before starting a new game
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (KMessageBox::warningTwoActions(this,
-#else
-        if (KMessageBox::warningYesNo(this,
-#endif
                                       i18n("Are you sure you want to quit the current game?"),
                                       i18nc("@title:window", "New Game"),
                                       KGuiItem(i18nc("@action:button", "Quit Game"), QStringLiteral("window-close")),
                                       KStandardGuiItem::cancel())
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             == KMessageBox::PrimaryAction)
-#else
-            == KMessageBox::Yes)
-#endif
         {
             // Start a new game
             initGame();
@@ -193,7 +179,7 @@ void MainWindow::showSettings()
     // Theme
     m_themeProvider->rediscoverThemes();
     m_currentThemeIdentifier = QString::fromLatin1(m_themeProvider->currentTheme()->identifier());
-    settingsDialog->addPage(new KgThemeSelector(m_themeProvider, KgThemeSelector::DefaultBehavior, settingsDialog), i18n("Theme"), QStringLiteral("games-config-theme"));
+    settingsDialog->addPage(new KGameThemeSelector(m_themeProvider, KGameThemeSelector::DefaultBehavior, settingsDialog), i18n("Theme"), QStringLiteral("games-config-theme"));
     // Arena
     settingsDialog->addPage(new ArenaSelector(settingsDialog, Settings::self(), &m_tempRandomArenaModeArenaList, ArenaSelector::DefaultBehavior), i18n("Arena"), QStringLiteral("games-config-board"));
     // Player
@@ -223,7 +209,7 @@ void MainWindow::settingsDialogCanceled()
     m_tempRandomArenaModeArenaList.clear();
     if(m_currentThemeIdentifier != QString::fromLatin1(m_themeProvider->currentTheme()->identifier()))
     {
-        const QList<const KgTheme*> themeList = m_themeProvider->themes();
+        const QList<const KGameTheme*> themeList = m_themeProvider->themes();
         for(const auto& theme: themeList)
         {
             if(QString::fromLatin1(theme->identifier()) == m_currentThemeIdentifier)
@@ -247,19 +233,11 @@ void MainWindow::close()
         m_game->pause();
     }
     // Confirm before closing
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     if(KMessageBox::warningTwoActions(this,
-#else
-    if(KMessageBox::warningYesNo(this,
-#endif
                                  i18n("Are you sure you want to quit Granatier?"),
                                  i18nc("To quit Granatier", "Quit"),
                                  KStandardGuiItem::quit(), KStandardGuiItem::cancel())
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
        == KMessageBox::PrimaryAction)
-#else
-       == KMessageBox::Yes)
-#endif
     {
         KXmlGuiWindow::close();
     }
